# FITS headers for test.fits

Keyword | Value | Comment
--- | --- | ---
HDU #0 in test.fits
SIMPLE | True | conforms to FITS standard
BITPIX | 8 | array data type
NAXIS | 0 | number of array dimensions
EXTEND | True |
HDU #1 in test.fits
XTENSION | BINTABLE | binary table extension
BITPIX | 8 | array data type
NAXIS | 2 | number of array dimensions
NAXIS1 | 16 | length of dimension 1
NAXIS2 | 3 | length of dimension 2
PCOUNT | 0 | number of group parameters
GCOUNT | 1 | number of groups
TFIELDS | 2 | number of table fields
TTYPE1 | foo |
TFORM1 | D |
TTYPE2 | bar |
TFORM2 | D |
ORDERING | NESTED |
COMMENT | This is a comment.
HISTORY | This is a history line. <This should be escaped.>